# edl-cr

A CLI tool to run code.

# Dev

- [Mypy Type Check Coverage Report](./dev/reports/mypy/index.html)

<!-- Test Report: ./dev/reports/test/index.html
Coverage Report: ./dev/reports/coverage/index.html -->
